@@ -52,7 +52,7 @@ class Issue(RawIssue):
         if is_dataclass(raw_issue):
             raw_issue = asdict(raw_issue)
         params = filter_kwargs(Issue, raw_issue | {"file": file, "id": issue_id})
-        for i, obj in enumerate(params["affected_lines"]):
+        for i, obj in enumerate(params.get("affected_lines") or []):
             d = obj if isinstance(obj, dict) else asdict(obj)
             params["affected_lines"][i] = Issue.AffectedCode(
                 **filter_kwargs(Issue.AffectedCode, {"file": file} | d)
@@ -72,6 +72,15 @@ class Issue(RawIssue):
         return url
 
 
+@dataclass
+class ProcessingWarning:
+    """
+    Warning generated during code review of files
+    """
+    message: str = field()
+    file: str | None = field(default=None)
+
+
 @dataclass
 class Report:
     class Format(StrEnum):
@@ -83,8 +92,9 @@ class Report:
     number_of_processed_files: int = field(default=0)
     total_issues: int = field(init=False)
     created_at: str = field(default_factory=lambda: datetime.now().strftime("%Y-%m-%d %H:%M:%S"))
-    model: str = field(default_factory=lambda: mc.config().MODEL)
+    model: str = field(default_factory=lambda: mc.config().MODEL or "")
     pipeline_out: dict = field(default_factory=dict)
+    processing_warnings: list[ProcessingWarning] = field(default_factory=list)
 
     @property
     def plain_issues(self):
